@@ -16,7 +16,7 @@ class ReadMsNet(Provider, Std):
         return self._get_content('{}/manga/{}')
 
     def get_manga_name(self) -> str:
-        return self._get_name(r'\.net/(?:manga|r)/([^/]+)')
+        return self._get_name(r'\.\w{2,7}/(?:manga|r)/([^/]+)')
 
     def get_chapters(self):
         return self._elements('.table-striped td > a')
